@@ -7,9 +7,12 @@
 #ifndef EDITORPLUGININTERFACE_H
 #define EDITORPLUGININTERFACE_H
 
-#include <QObject>
-#include "typenames.h"
 #include "graphtheory_export.h"
+#include "typenames.h"
+#include <KPluginMetaData>
+#include <QObject>
+
+#include <memory>
 
 class QUrl;
 class QDialog;
@@ -32,7 +35,7 @@ public:
      * @param componentData is description of the plugin
      * @param parent The parent object for the plugin.
      */
-    explicit EditorPluginInterface(const QString &componentName, QObject *parent);
+    explicit EditorPluginInterface(QObject *parent, const KPluginMetaData &data);
 
     ~EditorPluginInterface() override;
 
@@ -41,15 +44,10 @@ public:
     /**
      * @return display name of plugin, if nothing is set returns componentName
      */
-    virtual QString displayName();
-
-    /**
-     * set display name of plugin
-     */
-    virtual void setDisplayName(const QString &name);
+    virtual QString displayName() const;
 
 private:
-    const QScopedPointer<EditorPluginInterfacePrivate> d;
+    const std::unique_ptr<EditorPluginInterfacePrivate> d;
 };
 }
 
