@@ -6,14 +6,14 @@
 
 #include "qsglinenode.h"
 #include "qsgarrowheadnode.h"
-#include <QSGGeometry>
 #include <QColor>
+#include <QSGGeometry>
 
 using namespace GraphTheory;
 
 QSGLineNode::QSGLineNode()
     : m_geometry(QSGGeometry::defaultAttributes_Point2D(), 2)
-    , m_arrowHead(0)
+    , m_arrowHead(nullptr)
 {
     m_material.setColor(QColor(0, 0, 0));
     setMaterial(&m_material);
@@ -40,9 +40,9 @@ void QSGLineNode::setLine(const QPointF &from, const QPointF &to)
     markDirty(QSGNode::DirtyGeometry);
 }
 
-void QSGLineNode::setColor(const QColor& color)
+void QSGLineNode::setColor(const QColor &color)
 {
-    QSGFlatColorMaterial *m = static_cast<QSGFlatColorMaterial*>(material());
+    QSGFlatColorMaterial *m = static_cast<QSGFlatColorMaterial *>(material());
     m->setColor(color);
     if (m_arrowHead) {
         m_arrowHead->setColor(color);
@@ -60,6 +60,6 @@ void QSGLineNode::setDirection(EdgeType::Direction direction)
     if (m_arrowHead && direction == EdgeType::Bidirectional) {
         removeChildNode(m_arrowHead);
         delete m_arrowHead;
-        m_arrowHead = 0;
+        m_arrowHead = nullptr;
     }
 }
